pub struct EmbeddedAssetRegistry { /* private fields */ }Expand description
A Resource that manages “rust source files” in a virtual in memory Dir, which is intended
to be shared with a MemoryAssetReader.
Generally this should not be interacted with directly. The embedded_asset will populate this.
Implementations
Sourceimpl EmbeddedAssetRegistry
impl EmbeddedAssetRegistry
Sourcepub fn insert_asset(
&self,
full_path: PathBuf,
asset_path: &Path,
value: impl Into<Value>,
)
pub fn insert_asset( &self, full_path: PathBuf, asset_path: &Path, value: impl Into<Value>, )
Inserts a new asset. full_path is the full path (as file would return for that file, if it was capable of
running in a non-rust file). asset_path is the path that will be used to identify the asset in the embedded
AssetSource. value is the bytes that will be returned for the asset. This can be
either a &'static [u8] or a Vec<u8>.
Sourcepub fn insert_meta(
&self,
full_path: &Path,
asset_path: &Path,
value: impl Into<Value>,
)
pub fn insert_meta( &self, full_path: &Path, asset_path: &Path, value: impl Into<Value>, )
Inserts new asset metadata. full_path is the full path (as file would return for that file, if it was capable of
running in a non-rust file). asset_path is the path that will be used to identify the asset in the embedded
AssetSource. value is the bytes that will be returned for the asset. This can be either
a &'static [u8] or a Vec<u8>.
Sourcepub fn remove_asset(&self, full_path: &Path) -> Option<Data>
pub fn remove_asset(&self, full_path: &Path) -> Option<Data>
Removes an asset stored using full_path (the full path as file would return for that file, if it was capable of
running in a non-rust file). If no asset is stored with at full_path its a no-op.
It returning Option contains the originally stored Data or None.
Sourcepub fn register_source(&self, sources: &mut AssetSourceBuilders)
pub fn register_source(&self, sources: &mut AssetSourceBuilders)
Registers the EMBEDDED AssetSource with the given AssetSourceBuilders.